@@ -15,22 +15,28 @@ class CreateTicketAPIView(LoginRequiredMixin, CreateAPIView):
         user_agent = self.request.user_agent
         
         if user_agent.is_mobile:
-            device = "Mobile",
+            device = "mobile"
         elif user_agent.is_pc:
-            device = "PC"
+            device = "pc"
         elif user_agent.is_tablet:
-            device = "Tablet"
+            device = "tablet"
         else:
-            device = "Unknown"
+            device = "unknown"
 
         user_meta = {
-            "Browser": user_agent.browser.family + " " + user_agent.browser.version_string,
-            "Operating System": user_agent.os.family + " " + user_agent.os.version_string,
-            "Device": user_agent.device.family,
-            "Mobile/Tablet/PC": device,
-            "IP Address": self.request.META['REMOTE_ADDR']
+            "browser": {
+                "family": str.lower(user_agent.browser.family),
+                "version": user_agent.browser.version_string
+            },
+            "os": {
+                "family": str.lower(user_agent.os.family),
+                "version": user_agent.os.version_string
+            },
+            "device": str.lower(user_agent.device.family),
+            "mobile_tablet_or_pc": device,
+            "ip_address": self.request.META['REMOTE_ADDR']
         }
-
+        
         instance = serializer.save(user=self.request.user, site=Site.objects.get_current(), user_meta=user_meta)
 
         # filter and assign teams by site and category
